@@ -3,7 +3,6 @@
 // Purpose:     wxSpinButton
 // Author:      Robert
 // Modified by:
-// RCS-ID:      $Id$
 // Copyright:   (c) Robert Roebling
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -15,10 +14,6 @@
 
 #include "wx/spinbutt.h"
 
-#ifndef WX_PRECOMP
-    #include "wx/utils.h"
-#endif
-
 #include <gtk/gtk.h>
 
 //-----------------------------------------------------------------------------
@@ -38,7 +33,7 @@ gtk_value_changed(GtkSpinButton* spinbutton, wxSpinButton* win)
     const double value = gtk_spin_button_get_value(spinbutton);
     const int pos = int(value);
     const int oldPos = win->m_pos;
-    if (!win->m_hasVMT || g_blockEventsOnDrag || pos == oldPos)
+    if (g_blockEventsOnDrag || pos == oldPos)
     {
         win->m_pos = pos;
         return;
@@ -72,13 +67,6 @@ gtk_value_changed(GtkSpinButton* spinbutton, wxSpinButton* win)
 // wxSpinButton
 //-----------------------------------------------------------------------------
 
-IMPLEMENT_DYNAMIC_CLASS(wxSpinButton,wxControl)
-IMPLEMENT_DYNAMIC_CLASS(wxSpinEvent, wxNotifyEvent)
-
-BEGIN_EVENT_TABLE(wxSpinButton, wxControl)
-    EVT_SIZE(wxSpinButton::OnSize)
-END_EVENT_TABLE()
-
 wxSpinButton::wxSpinButton()
 {
     m_pos = 0;
@@ -91,14 +79,8 @@ bool wxSpinButton::Create(wxWindow *parent,
                           long style,
                           const wxString& name)
 {
-    wxSize new_size = size,
-           sizeBest = DoGetBestSize();
-    new_size.x = sizeBest.x;            // override width always
-    if (new_size.y == -1)
-        new_size.y = sizeBest.y;
-
-    if (!PreCreation( parent, pos, new_size ) ||
-        !CreateBase( parent, id, pos, new_size, style, wxDefaultValidator, name ))
+    if (!PreCreation(parent, pos, size) ||
+        !CreateBase(parent, id, pos, size, style, wxDefaultValidator, name))
     {
         wxFAIL_MSG( wxT("wxSpinButton creation failed") );
         return false;
@@ -109,6 +91,11 @@ bool wxSpinButton::Create(wxWindow *parent,
     m_widget = gtk_spin_button_new_with_range(0, 100, 1);
     g_object_ref(m_widget);
 
+    gtk_entry_set_width_chars(GTK_ENTRY(m_widget), 0);
+#if GTK_CHECK_VERSION(3,12,0)
+    if (gtk_check_version(3,12,0) == NULL)
+        gtk_entry_set_max_width_chars(GTK_ENTRY(m_widget), 0);
+#endif
     gtk_spin_button_set_wrap( GTK_SPIN_BUTTON(m_widget),
                               (int)(m_windowStyle & wxSP_WRAP) );
 
@@ -117,7 +104,7 @@ bool wxSpinButton::Create(wxWindow *parent,
 
     m_parent->DoAddChild( this );
 
-    PostCreation(new_size);
+    PostCreation(size);
 
     return true;
 }
@@ -167,14 +154,6 @@ void wxSpinButton::SetRange(int minVal, int maxVal)
     GtkEnableEvents();
 }
 
-void wxSpinButton::OnSize( wxSizeEvent &WXUNUSED(event) )
-{
-    wxCHECK_RET( (m_widget != NULL), wxT("invalid spin button") );
-
-    m_width = DoGetBestSize().x;
-    gtk_widget_set_size_request( m_widget, m_width, m_height );
-}
-
 bool wxSpinButton::Enable( bool enable )
 {
     if (!base_type::Enable(enable))
@@ -199,14 +178,34 @@ void wxSpinButton::GtkEnableEvents() const
         (gpointer)gtk_value_changed, (void*) this);
 }
 
-GdkWindow *wxSpinButton::GTKGetWindow(wxArrayGdkWindows& WXUNUSED(windows)) const
+GdkWindow *wxSpinButton::GTKGetWindow(wxArrayGdkWindows& windows) const
 {
+#ifdef __WXGTK3__
+    void wxGTKFindWindow(GtkWidget* widget, wxArrayGdkWindows& windows);
+    wxGTKFindWindow(m_widget, windows);
+    return NULL;
+#else
+    wxUnusedVar(windows);
     return GTK_SPIN_BUTTON(m_widget)->panel;
+#endif
 }
 
 wxSize wxSpinButton::DoGetBestSize() const
 {
-    wxSize best(15, 26); // FIXME
+    wxSize best = base_type::DoGetBestSize();
+#ifdef __WXGTK3__
+    GtkStyleContext* sc = gtk_widget_get_style_context(m_widget);
+    GtkBorder pad = { 0, 0, 0, 0 };
+    gtk_style_context_get_padding(sc, gtk_style_context_get_state(sc), &pad);
+    best.x -= pad.left + pad.right;
+#else
+    gtk_widget_ensure_style(m_widget);
+    int w = PANGO_PIXELS(pango_font_description_get_size(m_widget->style->font_desc));
+    w &= ~1;
+    if (w < 6)
+        w = 6;
+    best.x = w + 2 * m_widget->style->xthickness;
+#endif
     CacheBestSize(best);
     return best;
 }
@@ -215,9 +214,7 @@ wxSize wxSpinButton::DoGetBestSize() const
 wxVisualAttributes
 wxSpinButton::GetClassDefaultAttributes(wxWindowVariant WXUNUSED(variant))
 {
-    // TODO: overload to accept functions like gtk_spin_button_new?
-    // Until then use a similar type
-    return GetDefaultAttributesFromGTKWidget(gtk_button_new);
+    return GetDefaultAttributesFromGTKWidget(gtk_spin_button_new_with_range(0, 100, 1));
 }
 
-#endif
+#endif // wxUSE_SPINBTN
